@@ -14,7 +14,7 @@ class CollectorNetworkTestService:
     def __init__(self, config: Config, request_wrapper: Optional[GqlWrapper] = None):
         self._abort_on_error = True
 
-        self._request_wrapper = request_wrapper or GqlWrapper(mcd_id=config.mcd_id, mcd_token=config.mcd_token)
+        self._request_wrapper = request_wrapper or GqlWrapper(config)
 
     @manage_errors
     def echo_telnet_test(self, **kwargs):
