@@ -2,10 +2,13 @@ import click
 import click_config_file
 
 import montecarlodata.settings as settings
+from montecarlodata.common import create_mc_client
 from montecarlodata.integrations.onboarding.bi.reports import ReportsOnboardingService
 from montecarlodata.common.commands import DISAMBIGUATE_DC_OPTIONS
 from montecarlodata.common.resources import CloudResourceService
 from montecarlodata.integrations.info.status import OnboardingStatusService
+from montecarlodata.integrations.onboarding.data_lake.databricks import DatabricksOnboardingService, \
+    DEFAULT_SECRET_NAME, DEFAULT_SECRET_SCOPE
 from montecarlodata.integrations.onboarding.data_lake.events import EventsOnboardingService
 from montecarlodata.integrations.onboarding.data_lake.glue_athena import GlueAthenaOnboardingService
 from montecarlodata.integrations.onboarding.data_lake.hive import HiveOnboardingService
@@ -23,6 +26,7 @@ from montecarlodata.integrations.onboarding.fields import (
     HIVE_S3_CONNECTION_TYPE,
     PRESTO_S3_CONNECTION_TYPE,
     DATABRICKS_METASTORE_CONNECTION_TYPE,
+    DATABRICKS_DELTA_CONNECTION_TYPE,
     S3_METADATA_EVENT_TYPE,
     S3_QL_EVENT_TYPE,
     SECRETS_MANAGER_CREDENTIAL_MECHANISM,
@@ -59,7 +63,9 @@ S3_OPTIONS = [
 ]
 EVENT_OPTIONS = [
     click.option('--enable/--disable', 'toggle', help='Enable or disable events. Enables if not specified.',
-                 default=True)
+                 default=True),
+    click.option('--connection-id', help=CONNECTION_ID_VERBIAGE, required=False, type=click.UUID,
+                 callback=convert_uuid_callback)
 ]
 DATABASE_OPTIONS = [
     click.option('--host', help='Hostname.', required=True),
@@ -92,6 +98,37 @@ BI_OPTIONS = [
                  help='Whether to verify the SSL connection (uncheck for self-signed certs).')
 ]
 
+DATABRICKS_OPTIONS = [
+    click.option('--databricks-workspace-url', help='Databricks workspace URL.', required=True),
+    click.option('--databricks-workspace-id', help='Databricks workspace ID.', required=True),
+    click.option('--databricks-cluster-id', help='Databricks cluster ID.', required=True),
+    click.option('--databricks-token', help=f'Databricks access token. {PASSWORD_VERBIAGE}.', required=True,
+                 cls=AdvancedOptions, prompt_if_requested=True)
+]
+
+DATABRICKS_DATA_COLLECTOR_OPTIONS = [
+    click.option('--skip-secret-creation', help='Skip secret creation.', default=False, show_default=True, is_flag=True),
+    click.option('--databricks-secret-key', help='Databricks secret key.', default=DEFAULT_SECRET_NAME, show_default=True),
+    click.option('--databricks-secret-scope', help='Databricks secret scope.', default=DEFAULT_SECRET_SCOPE,
+                 show_default=True),
+    click.option('--skip-notebook-creation', help='Skip notebook creation.', default=False, show_default=True,
+                 is_flag=True, cls=AdvancedOptions,
+                 required_with_options=['databricks_job_id', 'databricks_job_name', 'databricks_notebook_path']),
+    click.option('--databricks-job-id', help='Databricks job id, required if notebook creation is skipped.',
+                 required=False, cls=AdvancedOptions,
+                 required_with_options=['skip_notebook_creation']),
+    click.option('--databricks-job-name', help='Databricks job name, required if notebook creation is skipped.',
+                 required=False, cls=AdvancedOptions,
+                 required_with_options=['skip_notebook_creation']),
+    click.option('--databricks-notebook-path', help='Databricks notebook path, required if notebook creation is skipped.',
+                 required=False, cls=AdvancedOptions,
+                 required_with_options=['skip_notebook_creation']),
+    click.option('--databricks-notebook-source',
+                 help='Databricks notebook source, required if notebook creation is skipped. (e.g. "resources/databricks/notebook/v1/collection.py")',
+                 required=False, cls=AdvancedOptions,
+                 required_with_options=['skip_notebook_creation']),
+]
+
 
 @click.group(help='Manage or integrate an asset with Monte Carlo.')
 def integrations():
@@ -246,11 +283,7 @@ def add_spark_http_mode(ctx, user, **kwargs):
 
 @integrations.command(help=f'Setup a Spark integration for Databricks. {SQL_VERBIAGE}.')
 @click.pass_obj
-@click.option('--workspace-url', help='Databricks workspace URL.', required=True)
-@click.option('--workspace-id', help='Databricks workspace ID.', required=True)
-@click.option('--cluster-id', help='Databricks cluster ID.', required=True)
-@click.option('--token', help=f'Databricks access token. {PASSWORD_VERBIAGE}.', required=True,
-              cls=AdvancedOptions, prompt_if_requested=True)
+@add_common_options(DATABRICKS_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def add_spark_databricks(ctx, **kwargs):
@@ -260,6 +293,36 @@ def add_spark_databricks(ctx, **kwargs):
     SparkOnboardingService(config=ctx['config']).onboard_spark(SPARK_DATABRICKS_CONFIG_TYPE, **kwargs)
 
 
+@integrations.command(help='Setup a Databricks metastore integration. For metadata and health queries.')
+@click.pass_obj
+@add_common_options(DATABRICKS_OPTIONS)
+@add_common_options(DATABRICKS_DATA_COLLECTOR_OPTIONS)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def add_databricks_metastore(ctx, **kwargs):
+    """
+    Onboard a databricks metastore
+    """
+    DatabricksOnboardingService(
+        config=ctx['config'], mc_client=create_mc_client(ctx)
+    ).onboard_databricks_metastore(connection_type=DATABRICKS_METASTORE_CONNECTION_TYPE, **kwargs)
+
+
+@integrations.command(help='Setup a Databricks Delta integration. For metadata queries on delta tables when using an external metastore in databricks.')
+@click.pass_obj
+@add_common_options(DATABRICKS_OPTIONS)
+@add_common_options(DATABRICKS_DATA_COLLECTOR_OPTIONS)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def add_databricks_delta(ctx, **kwargs):
+    """
+    Onboard a databricks delta service
+    """
+    DatabricksOnboardingService(
+        config=ctx['config'], mc_client=create_mc_client(ctx)
+    ).onboard_databricks_metastore(connection_type=DATABRICKS_DELTA_CONNECTION_TYPE, **kwargs)
+
+
 @integrations.command(help=f'Setup a Redshift integration. {WAREHOUSE_VERBIAGE}.')
 @click.pass_obj
 @click.option('--port', help='HTTP port.', default=5439, type=click.INT, show_default=True)
@@ -341,7 +404,7 @@ def add_self_hosted_credentials(ctx, mechanism, key, role, name, **kwargs):
     )
 
 
-@integrations.command(help=f'Toggle S3 events for Airflow task logs.')
+@integrations.command(help='Toggle S3 events for Airflow task logs.')
 @click.pass_obj
 @add_common_options(EVENT_OPTIONS)
 @add_common_options(ROLE_OPTIONS)
@@ -361,8 +424,6 @@ def toggle_airflow_log_events(ctx, toggle, role, **kwargs):
 @click.pass_obj
 @add_common_options(EVENT_OPTIONS)
 # Not using CONNECTION_OPTIONS as the value for "required" is different
-@click.option('--connection-id', help=CONNECTION_ID_VERBIAGE, required=False, type=click.UUID,
-              callback=convert_uuid_callback)
 @click.option('--connection-type', help='Type of the integration.', cls=AdvancedOptions,
               mutually_exclusive_options=['connection_id'],
               type=click.Choice(
@@ -386,7 +447,7 @@ def toggle_metadata_events(ctx, toggle, **kwargs):
               type=click.Choice([HIVE_S3_CONNECTION_TYPE, PRESTO_S3_CONNECTION_TYPE], case_sensitive=True),
               required=False)
 @click.option('--format-type', help='Query log format.',
-              type=click.Choice(['hive-emr', 'custom'], case_sensitive=True),
+              type=click.Choice(['hive-emr', 'hive-native', 'custom'], case_sensitive=True),
               required=False)
 @click.option('--source-format', help='Query log file format. Only required when "custom" is used.',
               type=click.Choice(['json', 'jsonl'], case_sensitive=True),
@@ -467,7 +528,7 @@ def add_looker_git(ctx, **kwargs):
     ReportsOnboardingService(config=ctx['config']).onboard_looker_git(**kwargs)
 
 
-@integrations.command(help=f'Setup a dbt Cloud integration.')
+@integrations.command(help='Setup a dbt Cloud integration.')
 @click.pass_obj
 @click.option('--dbt-cloud-api-token', 'dbt_cloud_api_token', help=f'dbt Cloud API token. {PASSWORD_VERBIAGE}.',
               required=True, cls=AdvancedOptions, prompt_if_requested=True)
