@@ -95,13 +95,22 @@ mutation testSparkCredentials($url:String!, $username:String!, $password:String!
 """
 
 TEST_SPARK_DATABRICKS_CRED_MUTATION = """
-mutation testSparkCredentials($workspaceUrl:String!, $workspaceId:String!, $clusterId:String!, $token:String!, $connectionOptions:ConnectionTestOptions) {
-  testSparkCredentials(databricks: {workspaceUrl:$workspaceUrl, workspaceId:$workspaceId, clusterId:$clusterId, token:$token}, connectionOptions:$connectionOptions) {
+mutation testSparkCredentials($databricksWorkspaceUrl:String!, $databricksWorkspaceId:String!, $databricksClusterId:String!, $databricksToken:String!, $connectionOptions:ConnectionTestOptions) {
+  testSparkCredentials(databricks: {databricksWorkspaceUrl:$databricksWorkspaceUrl, databricksWorkspaceId:$databricksWorkspaceId, databricksClusterId:$databricksClusterId, databricksToken:$databricksToken}, connectionOptions:$connectionOptions) {
     key
   }
 }
 """
 
+TEST_DATABRICKS_CRED_MUTATION = """
+mutation testDatabricksCredentials($databricksWorkspaceUrl:String!, $databricksWorkspaceId:String!, $databricksClusterId:String!, $databricksToken:String!, $connectionOptions:ConnectionTestOptions) {
+  testDatabricksCredentials(databricksConfig: {databricksWorkspaceUrl:$databricksWorkspaceUrl, databricksWorkspaceId:$databricksWorkspaceId, databricksClusterId:$databricksClusterId, databricksToken:$databricksToken}, connectionOptions:$connectionOptions) {
+    key
+    success
+  }
+}
+"""
+
 TEST_SNOWFLAKE_CRED_MUTATION = """
 mutation testSnowflakeCredentials($account:String, $password:String, $user:String, $warehouse:String, $connectionOptions:ConnectionTestOptions) {
   testSnowflakeCredentials(account:$account, password:$password, user:$user, warehouse:$warehouse, connectionOptions:$connectionOptions) {
@@ -127,7 +136,7 @@ mutation testSelfHostedCredentials($connectionType:String, $selfHostingMechanism
 """
 
 TOGGLE_EVENT_MUTATION = """
-mutation toggleEventConfig($dwId:UUID, $enable:Boolean!, $connectionId:String, $connectionType:String, $eventType:DataCollectorEventTypes!, $assumableRole:String, $externalId:String, $formatType:String, $sourceFormat:String, $mapping:JSONString) {
+mutation toggleEventConfig($dwId:UUID, $enable:Boolean!, $connectionId:UUID, $connectionType:String, $eventType:DataCollectorEventTypes!, $assumableRole:String, $externalId:String, $formatType:String, $sourceFormat:String, $mapping:JSONString) {
   toggleEventConfig(dwId:$dwId, enable:$enable, connectionId:$connectionId, connectionType:$connectionType, eventType: $eventType, assumableRole:$assumableRole, externalId:$externalId, formatType:$formatType, sourceFormat:$sourceFormat, mapping:$mapping){
     success
   }
@@ -189,22 +198,13 @@ query testExistingConnection($connectionId:UUID) {
 TEST_TABLEAU_CRED_MUTATION = """
 mutation testTableauCredentials($connectionOptions:ConnectionTestOptions, $password:String, $serverName:String!, $siteName:String!, $tokenName:String, $tokenValue:String, $username:String, $verifySsl:Boolean) {
   testTableauCredentials(connectionOptions:$connectionOptions, password:$password, serverName:$serverName, siteName:$siteName, tokenName:$tokenName, tokenValue:$tokenValue, username:$username, verifySsl:$verifySsl) {
+    key
     success
   }
 }
 
 """
 
-ADD_TABLEAU_CONNECTION_MUTATION = """
-mutation addTableauAccount($dcId:UUID, $password:String, $serverName:String!, $siteName:String!, $tokenName:String, $tokenValue:String, $username:String, $verifySsl:Boolean) {
-  addTableauAccount(dcId:$dcId, password:$password, serverName:$serverName, siteName:$siteName, tokenName:$tokenName, tokenValue:$tokenValue, username:$username, verifySsl:$verifySsl) {
-    tableauAccount {
-      uuid
-    }
-  }
-}
-"""
-
 TEST_LOOKER_METADATA_CRED_MUTATION = """
 mutation testLookerCredentials($baseUrl:String, $clientId:String, $clientSecret:String, $connectionOptions:ConnectionTestOptions, $verifySsl:Boolean) {
   testLookerCredentials(baseUrl:$baseUrl, clientId:$clientId, clientSecret:$clientSecret, connectionOptions:$connectionOptions, verifySsl:$verifySsl) {
