@@ -3,10 +3,10 @@ Command line tools
 """
 import copy
 import json
-from typing import Set
+from typing import Set, Optional
 
 import click
-from click import Option
+from click import Option, Context
 
 import montecarlodata.settings as settings
 from montecarlodata.common.common import normalize_gql
@@ -131,3 +131,13 @@ def convert_empty_str_callback(ctx_, param_, value):
     """
     if bool(value and not value.isspace()):
         return value
+
+
+def dump_help(cmd, parent: Optional[Context] = None):
+    """
+    Recursively echos help text for a cmd
+    """
+    ctx = click.core.Context(cmd, info_name=cmd.name, parent=parent)
+    click.echo(cmd.get_help(ctx), err=True)
+    for sub in getattr(cmd, 'commands', {}).values():
+        dump_help(sub, ctx)
